pub struct RemoteSupervisorHandle { /* private fields */ }Expand description
Handle to communicate with a remote supervisor
Implementations
Sourceimpl RemoteSupervisorHandle
impl RemoteSupervisorHandle
Sourcepub fn new(address: SupervisorAddress) -> Self
pub fn new(address: SupervisorAddress) -> Self
Create a new handle to a remote supervisor
Sourcepub async fn connect_tcp(
addr: impl Into<String>,
) -> Result<Self, DistributedError>
pub async fn connect_tcp( addr: impl Into<String>, ) -> Result<Self, DistributedError>
Sourcepub async fn connect_unix(
path: impl Into<String>,
) -> Result<Self, DistributedError>
pub async fn connect_unix( path: impl Into<String>, ) -> Result<Self, DistributedError>
Sourcepub async fn send_command(
&self,
cmd: RemoteCommand,
) -> Result<RemoteResponse, DistributedError>
pub async fn send_command( &self, cmd: RemoteCommand, ) -> Result<RemoteResponse, DistributedError>
Send a command to the remote supervisor
Errors
Returns an error if the connection fails or the command cannot be serialized.
Sourcepub async fn shutdown(&self) -> Result<(), DistributedError>
pub async fn shutdown(&self) -> Result<(), DistributedError>
Sourcepub async fn which_children(&self) -> Result<Vec<ChildInfo>, DistributedError>
pub async fn which_children(&self) -> Result<Vec<ChildInfo>, DistributedError>
Get list of children from remote supervisor
Errors
Returns an error if the remote connection fails or returns an unexpected response.
Sourcepub async fn terminate_child(&self, id: &str) -> Result<(), DistributedError>
pub async fn terminate_child(&self, id: &str) -> Result<(), DistributedError>
Terminate a child on the remote supervisor
Errors
Returns an error if the remote connection fails or returns an unexpected response.
Sourcepub async fn status(&self) -> Result<SupervisorStatus, DistributedError>
pub async fn status(&self) -> Result<SupervisorStatus, DistributedError>
Get status from remote supervisor
Errors
Returns an error if the remote connection fails or returns an unexpected response.