pub struct SupervisorServer<W: Worker> { /* private fields */ }Expand description
Server that wraps a SupervisorHandle and accepts remote commands
Implementations
Sourceimpl<W: Worker> SupervisorServer<W>
impl<W: Worker> SupervisorServer<W>
Sourcepub fn new(handle: SupervisorHandle<W>) -> Self
pub fn new(handle: SupervisorHandle<W>) -> Self
Create a new supervisor server wrapping a SupervisorHandle
Sourcepub async fn listen_unix(
self,
path: impl AsRef<Path>,
) -> Result<(), DistributedError>
pub async fn listen_unix( self, path: impl AsRef<Path>, ) -> Result<(), DistributedError>
Start listening on a Unix socket (Unix only)
Errors
Returns an error if the socket cannot be bound or a connection fails.
Sourcepub async fn listen_tcp(
self,
addr: impl AsRef<str>,
) -> Result<(), DistributedError>
pub async fn listen_tcp( self, addr: impl AsRef<str>, ) -> Result<(), DistributedError>
Start listening on a TCP socket
Errors
Returns an error if the socket cannot be bound or a connection fails.