pub struct SupervisorSpec<W: Worker> { /* private fields */ }Expand description
Describes a supervisor and its children in a tree structure.
Implementations
Sourceimpl<W: Worker> SupervisorSpec<W>
impl<W: Worker> SupervisorSpec<W>
Sourcepub fn new(name: impl Into<String>) -> Self
pub fn new(name: impl Into<String>) -> Self
Creates a new supervisor specification with the provided name.
Sourcepub fn with_restart_strategy(self, strategy: RestartStrategy) -> Self
pub fn with_restart_strategy(self, strategy: RestartStrategy) -> Self
Sets the restart strategy for this supervisor.
Sourcepub fn with_restart_intensity(self, intensity: RestartIntensity) -> Self
pub fn with_restart_intensity(self, intensity: RestartIntensity) -> Self
Sets the restart intensity for this supervisor.
Sourcepub fn with_worker(
self,
id: impl Into<String>,
factory: impl Fn() -> W + Send + Sync + 'static,
restart_policy: RestartPolicy,
) -> Self
pub fn with_worker( self, id: impl Into<String>, factory: impl Fn() -> W + Send + Sync + 'static, restart_policy: RestartPolicy, ) -> Self
Adds a worker child to this supervisor specification. The factory function is used to create new worker instances (e.g., for restarts).
Sourcepub fn with_supervisor(self, supervisor: SupervisorSpec<W>) -> Self
pub fn with_supervisor(self, supervisor: SupervisorSpec<W>) -> Self
Adds a nested supervisor child to this supervisor specification.