pub struct SupervisorHandle<W: Worker> { /* private fields */ }Expand description
Handle used to interact with a running supervisor tree.
Implementations
Sourceimpl<W: Worker> SupervisorHandle<W>
impl<W: Worker> SupervisorHandle<W>
Sourcepub fn start(spec: SupervisorSpec<W>) -> Self
pub fn start(spec: SupervisorSpec<W>) -> Self
Spawns a supervisor tree based on the provided specification.
Sourcepub async fn start_child(
&self,
id: impl Into<String>,
factory: impl Fn() -> W + Send + Sync + 'static,
restart_policy: RestartPolicy,
) -> Result<ChildId, SupervisorError>
pub async fn start_child( &self, id: impl Into<String>, factory: impl Fn() -> W + Send + Sync + 'static, restart_policy: RestartPolicy, ) -> Result<ChildId, SupervisorError>
Dynamically starts a new child worker
Sourcepub async fn start_child_linked(
&self,
id: impl Into<String>,
factory: impl Fn() -> W + Send + Sync + 'static,
restart_policy: RestartPolicy,
timeout: Duration,
) -> Result<ChildId, SupervisorError>
pub async fn start_child_linked( &self, id: impl Into<String>, factory: impl Fn() -> W + Send + Sync + 'static, restart_policy: RestartPolicy, timeout: Duration, ) -> Result<ChildId, SupervisorError>
Dynamically starts a new child worker with linked initialization.
This method waits for the worker’s initialization to complete before returning. If initialization fails or times out, an error is returned and the worker is not added.
Arguments
id- Unique identifier for the childfactory- Factory function to create the workerrestart_policy- How to handle worker termination after it starts runningtimeout- Maximum time to wait for initialization
Errors
SupervisorError::InitializationFailed- Worker initialization returned an errorSupervisorError::InitializationTimeout- Worker didn’t initialize within timeoutSupervisorError::ChildAlreadyExists- A child with this ID already existsSupervisorError::ShuttingDown- Supervisor is shutting down
Note
Initialization failures do NOT trigger restart policies. The worker must successfully initialize before restart policies take effect.
Sourcepub async fn terminate_child(&self, id: &str) -> Result<(), SupervisorError>
pub async fn terminate_child(&self, id: &str) -> Result<(), SupervisorError>
Dynamically terminates a child
Sourcepub async fn which_children(&self) -> Result<Vec<ChildInfo>, SupervisorError>
pub async fn which_children(&self) -> Result<Vec<ChildInfo>, SupervisorError>
Returns information about all children
Sourcepub async fn shutdown(&self) -> Result<(), SupervisorError>
pub async fn shutdown(&self) -> Result<(), SupervisorError>
Requests a graceful shutdown of the supervisor tree.
Sourcepub async fn restart_strategy(&self) -> Result<RestartStrategy, SupervisorError>
pub async fn restart_strategy(&self) -> Result<RestartStrategy, SupervisorError>
Returns the supervisor’s restart strategy.
Sourcepub async fn uptime(&self) -> Result<u64, SupervisorError>
pub async fn uptime(&self) -> Result<u64, SupervisorError>
Returns the supervisor’s uptime in seconds.